@@ -1,7 +1,5 @@
-# type: ignore
-
 """Platform and Python version compatibility support."""
 
 import sys
 
-WIN = sys.platform in ("win32", "cygwin")
+WIN: bool = sys.platform in ("win32", "cygwin")
